@@ -1,9 +1,9 @@
-/*  
-    Geodesy and Mapping C++ Library (GNU GaMa / GaMaLib)
+/*
+    GNU Gama -- adjustment of geodetic networks
     Copyright (C) 2002, 2003  Ales Cepek <cepek@gnu.org>
 
-    This file is part of the GNU GaMa / GaMaLib C++ Library.
-    
+    This file is part of the GNU Gama C++ library.
+
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 3 of the License, or
@@ -19,12 +19,8 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-/*
- *  $Id: ellipsoid.h,v 1.2 2007/06/26 15:04:08 cepek Exp $
- */
-
-#ifndef GNU_gama__gamalib____ellipsoid_H___________ELLIPSOID_H________
-#define GNU_gama__gamalib____ellipsoid_H___________ELLIPSOID_H________
+#ifndef GNU_gama__gnu_gama_local____ellipsoid_H___________ELLIPSOID_H________
+#define GNU_gama__gnu_gama_local____ellipsoid_H___________ELLIPSOID_H________
 
 namespace GNU_gama {
 
