@@ -1,9 +1,9 @@
-/*  
+/*
     GNU Gama -- adjustment of geodetic networks
-    Copyright (C) 2003  Ales Cepek <cepek@gnu.org>
+    Copyright (C) 2003, 2011  Ales Cepek <cepek@gnu.org>
 
     This file is part of the GNU Gama C++ library.
-    
+
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 3 of the License, or
@@ -19,11 +19,6 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-/*
- *  $Id: exception.h,v 1.2 2007/06/26 15:04:08 cepek Exp $
- */
-
-
 #ifndef GNU_gama__exception__exception_class_hierarchy_____exception_h
 #define GNU_gama__exception__exception_class_hierarchy_____exception_h
 
@@ -32,11 +27,19 @@
 
 namespace GNU_gama { namespace Exception {
 
-  //---  class base {
-  //---  public:
-  //---   virtual ~base() {}
-  //---  };
-  
+   /** \section GNU gama exceptions
+   *
+   * \a Exception::base and \a Exception::matvec are defined in
+   * <lib/matvec/inderr>
+   *
+   * Classes \a GNU_gama::local::Exception,
+   * GNU_gama::local::ParserException and
+   * GNU_gama::local::MatVecException are only typedefs to \a
+   * Exception::string, \a Exception::parser and
+   * GNU_gama::Exception::matvec respectively.
+   *
+   * Class \a g2d_exc is limited to Median namespace usage.
+  */
 
   class string : public base {
   public:
@@ -44,6 +47,12 @@ namespace GNU_gama { namespace Exception {
     const std::string  str;
 
     string(const std::string& s) : str(s) {}
+    ~string() throw() {}
+
+    string* clone() const { return new string(*this); }
+    void    raise() const { throw *this; }
+
+    const char* what() const throw() { return str.c_str(); }
   };
 
 
@@ -51,27 +60,24 @@ namespace GNU_gama { namespace Exception {
   public:
 
     adjustment(const char* s) : string(s) {}
+
+    adjustment* clone() const { return new adjustment(*this); }
+    void        raise() const { throw *this; }
   };
 
 
-  //---  class matvec : public string {
-  //---  public:
-  //---  
-  //---    const int error;
-  //---  
-  //---    matvec(int e, const char* s) : string(s), error(e) {}
-  //---  };
-
-
   class parser : public string {
   public:
 
     const int line, error_code;
 
-    parser(const std::string& s, int r, int c) 
-      : string(s), line(r), error_code(c) 
+    parser(const std::string& s, int r, int c)
+      : string(s), line(r), error_code(c)
       {
       }
+
+    parser* clone() const { return new parser(*this); }
+    void    raise() const { throw *this; }
   };
 
 
