@@ -1,24 +1,23 @@
-/*
-    GNU Gama C++ library
+/* GNU Gama -- adjustment of geodetic networks
     Copyright (C) 1999, 2006, 2010  Ales Cepek <cepek@fsv.cvut.cz>
                   2011  Vaclav Petras <wenzeslaus@gmail.com>
+                  2012  Ales Cepek <cepek@gnu.org>
 
-    This file is part of the GNU Gama C++ library
+   This file is part of the GNU Gama C++ library.
 
-    This library is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 3 of the License, or
-    (at your option) any later version.
+   This library is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 3, or (at your option)
+   any later version.
 
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-*/
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software Foundation,
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 /** \file network.cpp
  * \brief #GNU_gama::local::LocalNetwork class implementation
@@ -577,7 +576,15 @@ bool LocalNetwork::singular_coords(const Mat& A)
   for (PointData::iterator i=PD.begin(); i!=PD.end(); ++i)
     {
       LocalPoint&  p  = (*i).second;
-      if (!p.free_xy() || p.index_x()==0) continue;
+      if (p.fixed_xy() || !p.active_xy()) continue;
+
+      if(p.index_x() == 0 || p.index_y() == 0)
+      {
+          result = true;
+          p.unused_xy();
+          removed( (*i).first, rm_singular_xy );
+          continue;
+      }
 
       indx = p.index_x();
       indy = p.index_y();
