@@ -1,26 +1,25 @@
-/*
-    GNU Gama -- adjustment of geodetic networks
-    Copyright (C) 1999, 2006  Ales Cepek <cepek@fsv.cvut.cz>
+/* GNU Gama -- adjustment of geodetic networks
+   Copyright (C) 1999, 2006, 2012  Ales Cepek <cepek@gnu.org>
 
-    This file is part of the GNU Gama C++ library.
+   This file is part of the GNU Gama C++ library.
 
-    This library is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 3 of the License, or
-    (at your option) any later version.
+   This library is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 3, or (at your option)
+   any later version.
 
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-*/
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software Foundation,
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
-// LocalNetwork - Network Informations class (Informace o siti)
-// =========================================================================
+
+// LocalNetwork - Network Informations class
+// =========================================
 
 
 #ifndef gama_local_LocalNetwork_h
@@ -159,6 +158,10 @@ namespace GNU_gama { namespace local
 
     // ...  adjustment  ....................................................
 
+    bool is_adjusted() const
+    {
+      return tst_vyrovnani_;
+    }
     const Vec& solve()
     {
       vyrovnani_();
@@ -355,12 +358,3 @@ namespace GNU_gama { namespace local
 }}         /* namespace GNU_gama::local */
 
 #endif
-
-
-
-
-
-
-
-
-
