@@ -1,6 +1,6 @@
 /*
-    C++ Matrix/Vector templates (GNU Gama / matvec 1.0.01)
-    Copyright (C) 1999, 2007  Ales Cepek <cepek@gnu.org>
+    C++ Matrix/Vector templates (GNU Gama / matvec)
+    Copyright (C) 1999, 2007, 2012  Ales Cepek <cepek@gnu.org>
 
     This file is part of the GNU Gama C++ Matrix/Vector template library.
 
@@ -23,7 +23,6 @@
 #define GNU_gama_gMatVec_Mat__h_
 
 #include <iostream>
-#include <cstdarg>
 #include <matvec/matbase.h>
 #include <matvec/array.h>
 
@@ -45,25 +44,6 @@ public:
   Mat() {}
   Mat(Index r, Index c) : MatBase<Float, Exc>(r, c, r*c) {}
   Mat(const TransMat<Float, Exc>&);
-  Mat(Index r, Index c, Float m11 ...) : MatBase<Float, Exc>(r, c, r*c)
-    {
-      using namespace std;
-      iterator p=this->begin();
-      iterator e=this->end();
-      if (p == e)
-        throw Exc(Exception::BadRank, "Mat::Mat(Index, Float ...)");
-      *p = m11;
-      ++p;
-
-      va_list  ap;
-      va_start(ap, m11);
-      while (p!=e)
-        {
-          *p = va_arg(ap, Float);
-          ++p;
-        }
-      va_end(ap);
-    }
 
   Float& operator()(Index r, Index c) {
     Float *m = this->begin();
@@ -75,14 +55,14 @@ public:
   }
 
   Mat operator*(Float f) const {
-    Mat t(this->rows(), this->cols()); mul(f, t); return t;
+    Mat t(this->rows(), this->cols()); this->mul(f, t); return t;
   }
   Mat operator+(const Mat& M) const {
     if (this->rows() != M.rows() || this->cols() != M.cols())
       throw Exc(Exception::BadRank, "Mat::operator+(const Mat& M) const");
 
     Mat T(this->rows(), this->cols());
-    add(M, T);
+    this->add(M, T);
     return T;
   }
   Mat operator-(const Mat& M) const {
@@ -90,7 +70,7 @@ public:
       throw Exc(Exception::BadRank, "Mat::operator-(const Mat& M) const");
 
     Mat T(this->rows(), this->cols());
-    sub(M, T);
+    this->sub(M, T);
     return T;
   }
 
@@ -99,7 +79,7 @@ public:
 
   typename MatVecBase<Float, Exc>::ListInitialiser operator=(Float x)
   {
-    return list_init(x);
+    return this->list_init(x);
   }
 
 private:
@@ -121,7 +101,8 @@ Mat<Float, Exc>
 operator* (const MatBase<Float, Exc> &A, const MatBase<Float, Exc> &B)
   {
     if (A.cols() != B.rows())
-      throw Exc(Exception::BadRank, "Mat operator* (const MatBase&, const MatBase&)");
+      throw Exc(Exception::BadRank,
+                "Mat operator* (const MatBase&, const MatBase&)");
 
     Mat<Float, Exc> C(A.rows(), B.cols());
     typename Mat<Float, Exc>::iterator c = C.begin();
@@ -144,7 +125,8 @@ Mat<Float, Exc>
 operator+(const MatBase<Float, Exc> &A,const MatBase<Float, Exc> &B)
   {
     if (A.rows() != B.rows() || A.cols() != B.cols())
-      throw Exc(Exception::BadRank, "Mat operator+(const MatBase &A, const MatBase &B)");
+      throw Exc(Exception::BadRank,
+                "Mat operator+(const MatBase &A, const MatBase &B)");
 
     Mat<Float, Exc> C(A.rows(), A.cols());
     for (Index i=1; i<=A.rows(); i++)
@@ -160,7 +142,8 @@ Mat<Float, Exc>
 operator-(const MatBase<Float, Exc> &A, const MatBase<Float, Exc> &B)
   {
     if (A.rows() != B.rows() || A.cols() != B.cols())
-      throw Exc(Exception::BadRank, "Mat operator-(const MatBase &A,const MatBase &B)");
+      throw Exc(Exception::BadRank,
+                "Mat operator-(const MatBase &A,const MatBase &B)");
 
     Mat<Float, Exc> C(A.rows(), A.cols());
     for (Index i=1; i<=A.rows(); i++)
@@ -228,7 +211,7 @@ void Mat<Float, Exc>::invert()
           for (jj=step; jj<N; jj++)
             {
               e = entry(i, indc[jj]);
-              if (Abs(e) > Abs(pivot))
+              if (this->Abs(e) > this->Abs(pivot))
                 {
                   pivot = e; p_row = ii; p_col = jj;
                 }
